@@ -1,3 +1,4 @@
+#' @importFrom filehash registerFormatDB
 .onLoad <- function(lib, pkg) {
     ## Register 'filehash' database format
     r <- list(create = createSQLite, initialize = initializeSQLite)
@@ -6,8 +7,8 @@
 
 .onAttach <- function(lib, pkg) {
     dcf <- read.dcf(file.path(lib, pkg, "DESCRIPTION"))
-    msg <- gettextf("%s (%s %s)", dcf[, "Title"],
-                    as.character(dcf[, "Version"]), dcf[, "Date"])
+    msg <- gettextf("%s (%s)", dcf[, "Title"],
+                    as.character(dcf[, "Version"]))
     packageStartupMessage(paste(strwrap(msg), collapse = "\n"))
 }
 
